@@ -1,6 +1,6 @@
 package Resque;
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-$Resque::VERSION = '0.24';
+$Resque::VERSION = '0.25';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
@@ -43,11 +43,10 @@ has failures => (
     handles => [qw/ throw /]
 );
 
-has worker => (
-    is      => 'ro',
-    lazy    => 1,
-    default => sub { $_[0]->worker_class->new( resque => $_[0] ) }
-);
+sub worker {
+    my $self = shift;
+    $self->worker_class->new( resque => $self );
+}
 
 sub push {
     my ( $self, $queue, $job ) = @_;
@@ -177,7 +176,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.24
+version 0.25
 
 =head1 SYNOPSIS
 
@@ -257,13 +256,13 @@ By default 'resque' is used.
 
 Failures handler. See L<Resque::Failures>.
 
+=head1 METHODS
+
 =head2 worker
 
-A L<Resque::Worker> on this resque instance.
+Returns a new L<Resque::Worker> on this resque instance.
 It can have plugin/roles applied. See L<Resque::Pluggable>.
 
-=head1 METHODS
-
 =head2 push
 
 Pushes a job onto a queue. Queue name should be a string and the
